@@ -4,10 +4,12 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the licence or (at
+ * by the Free Software Foundation; either version 2.1 of the licence or (at
  * your option) any later version.
  *
  * See the included COPYING file for more information.
+ *
+ * Author: Stef Walter <stefw@gnome.org>
  */
 
 #include "config.h"
@@ -73,10 +75,10 @@ enum {
 };
 
 /* Thread safe: no changes between construct and finalize */
-typedef struct _SecretItemPrivate {
+struct _SecretItemPrivate {
 	SecretService *service;
 	GCancellable *cancellable;
-} SecretItemPrivate;
+};
 
 static GInitableIface *secret_item_initable_parent_iface = NULL;
 
