@@ -4,10 +4,12 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the licence or (at
+ * by the Free Software Foundation; either version 2.1 of the licence or (at
  * your option) any later version.
  *
  * See the included COPYING file for more information.
+ *
+ * Author: Stef Walter <stefw@gnome.org>
  */
 
 #include "config.h"
@@ -53,12 +55,12 @@
  * The class for #SecretPrompt.
  */
 
-typedef struct _SecretPromptPrivate {
+struct _SecretPromptPrivate {
 	/* Locked by mutex */
 	GMutex mutex;
 	gint prompted;
 	GVariant *last_result;
-} SecretPromptPrivate;
+};
 
 G_DEFINE_TYPE (SecretPrompt, secret_prompt, G_TYPE_DBUS_PROXY);
 
