@@ -5,10 +5,12 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the licence or (at
+ * by the Free Software Foundation; either version 2.1 of the licence or (at
  * your option) any later version.
  *
  * See the included COPYING file for more information.
+ *
+ * Author: Stef Walter <stefw@gnome.org>
  */
 
 #include "config.h"
@@ -108,7 +110,7 @@ enum {
 	PROP_COLLECTIONS
 };
 
-typedef struct _SecretServicePrivate {
+struct _SecretServicePrivate {
 	/* No change between construct and finalize */
 	GCancellable *cancellable;
 	SecretServiceFlags init_flags;
@@ -117,7 +119,7 @@ typedef struct _SecretServicePrivate {
 	GMutex mutex;
 	gpointer session;
 	GHashTable *collections;
-} SecretServicePrivate;
+};
 
 G_LOCK_DEFINE (service_instance);
 static gpointer service_instance = NULL;
