@@ -4,10 +4,12 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the licence or (at
+ * by the Free Software Foundation; either version 2.1 of the licence or (at
  * your option) any later version.
  *
  * See the included COPYING file for more information.
+ *
+ * Author: Stef Walter <stefw@gnome.org>
  */
 
 #ifndef SECRET_API_SUBJECT_TO_CHANGE
@@ -27,7 +29,6 @@
 #include <secret/secret-enum-types.h>
 #include <secret/secret-item.h>
 #include <secret/secret-prompt.h>
-#include <secret/secret-schemas.h>
 #include <secret/secret-service.h>
 #include <secret/secret-value.h>
 
